@@ -1,17 +1,16 @@
 # coding: utf-8
-#
-# AUTHOR: Igor Kalnitsky <igor.kalnitsky@gmail.com>
-# URL: http://www.kalnitsky.org.ua/
-# LICENSE: GPLv3
+
+"""
+    AUTHOR: Igor Kalnitsky <igor.kalnitsky@gmail.com>
+    URL: http://www.kalnitsky.org.ua/
+"""
 
 import nautilus
 import pynotify
-import getpass
-import os
-import gtk
 import urllib
 import urllib2
-
+import gtk
+import os
 
 class XsnippetExtension(nautilus.MenuProvider):
     """
@@ -27,7 +26,8 @@ class XsnippetExtension(nautilus.MenuProvider):
 
     languages = {
             ".c": "C",
-            ".cpp": "C++", "cxx": "C++", ".h": "C++", ".hpp" : "C++", ".hxx": "C++",
+            ".cpp": "C++", "cxx": "C++",
+            ".h": "C++", ".hpp": "C++", ".hxx": "C++",
             ".cs": "C#",
             ".java": "Java",
             ".py": "Python",
@@ -61,12 +61,10 @@ class XsnippetExtension(nautilus.MenuProvider):
             ".txt": "Text",
     }
 
-
     def __init__(self):
         pynotify.init("nautilus-xsnippet")
         self.clipboard = gtk.clipboard_get()
 
-
     def sendFile(self, filename):
         """
             Send file to xsnippet.tk and return link to last one.
@@ -76,38 +74,35 @@ class XsnippetExtension(nautilus.MenuProvider):
         language = "Autodetection"
         title = os.path.basename(filename)
         extension = os.path.splitext(filename)[1]
-        if XsnippetExtension.languages.has_key(extension):
+        if extension in XsnippetExtension.languages:
             language = XsnippetExtension.languages[extension]
 
         data = {
-            "title" : title,
-            "content" : file(filename).read(),
-            "language" : language,
-            "author" : getpass.getuser(),
+            "title": title,
+            "content": open(filename).read(),
+            "language": language,
+            "author": os.environ.get("USER"),
         }
 
-        request = urllib2.Request(url = XsnippetExtension.API_URL,
-                                  data = urllib.urlencode(data))
+        request = urllib2.Request(url=XsnippetExtension.API_URL,
+                                  data=urllib.urlencode(data))
         response = urllib2.urlopen(request)
 
         if response.getcode() == 200:
             return response.geturl()
         return None
 
-
     def menu_click(self, menu, sourcefile):
         """
             'Send to xsnippet.tk' item handler.
 
             Send file to xsnippet and show notification.
         """
-
         title = ''
         message = ''
-
         snippeturl = self.sendFile(sourcefile.get_uri()[7:])
 
-        if not snippeturl:
+        if snippeturl is None:
             title = "Error"
             message = "Can't post file"
         else:
@@ -117,25 +112,24 @@ class XsnippetExtension(nautilus.MenuProvider):
             self.clipboard.set_text(message)
             self.clipboard.store()
 
-        notification = pynotify.Notification(title, message, XsnippetExtension.ICON)
+        notification = pynotify.Notification(title, message,
+                                             XsnippetExtension.ICON)
         notification.show()
 
-
     def get_file_items(self, window, files):
         """
             Show 'Send to xsnippet.tk' item only for 1 selected file.
         """
 
-        if len(files) != 1 or files[0].is_directory() == True:
+        if len(files) != 1 or files[0].is_directory():
             return
 
         item = nautilus.MenuItem(
                 "XsnippetExtension::send_to_xsnippet",
                 "Send to xsnippet.tk",
-                "Send the current file to xsnippet.tk"
+                "Send the current file to xsnippet.tk",
         )
 
         item.set_property("icon", "nautilus-xsnippet")
         item.connect("activate", self.menu_click, files[0])
         return [item]
-
